@@ -1,4 +1,3 @@
-require 'base64'
 require 'delegate'
 require 'time'
 
@@ -18,46 +17,36 @@ module VCR
           hash = hash_or_string
 
           if hash.has_key?('base64_string')
-            string = Base64.decode64(hash['base64_string'])
-            force_encode_string(string, hash['encoding'])
+            base64_decoded = hash['base64_string'].unpack1('m')
+            force_encode_string(base64_decoded, hash['encoding'])
           else
             try_encode_string(hash['string'], hash['encoding'])
           end
         end
 
-        if "".respond_to?(:encoding)
-          def force_encode_string(string, encoding)
-            return string unless encoding
-            string.force_encoding(encoding)
-          end
+        def force_encode_string(string, encoding)
+          return string unless encoding
+          string.force_encoding(encoding)
+        end
 
-          def try_encode_string(string, encoding_name)
-            return string if encoding_name.nil?
+        def try_encode_string(string, encoding_name)
+          return string if encoding_name.nil? || string.nil?
 
-            encoding = Encoding.find(encoding_name)
-            return string if string.encoding == encoding
+          encoding = Encoding.find(encoding_name)
+          return string if string.encoding == encoding
 
-            # ASCII-8BIT just means binary, so encoding to it is nonsensical
-            # and yet "\u00f6".encode("ASCII-8BIT") raises an error.
-            # Instead, we'll force encode it (essentially just tagging it as binary)
-            return string.force_encoding(encoding) if encoding == Encoding::BINARY
+          # ASCII-8BIT just means binary, so encoding to it is nonsensical
+          # and yet "\u00f6".encode("ASCII-8BIT") raises an error.
+          # Instead, we'll force encode it (essentially just tagging it as binary)
+          return string.force_encoding(encoding) if encoding == Encoding::BINARY
 
-            string.encode(encoding)
-          rescue EncodingError => e
-            struct_type = name.split('::').last.downcase
-            warn "VCR: got `#{e.class.name}: #{e.message}` while trying to encode the #{string.encoding.name} " +
-                 "#{struct_type} body to the original body encoding (#{encoding}). Consider using the " +
-                 "`:preserve_exact_body_bytes` option to work around this."
-            return string
-          end
-        else
-          def force_encode_string(string, encoding)
-            string
-          end
-
-          def try_encode_string(string, encoding)
-            string
-          end
+          string.encode(encoding)
+        rescue EncodingError => e
+          struct_type = name.split('::').last.downcase
+          warn "VCR: got `#{e.class.name}: #{e.message}` while trying to encode the #{string.encoding.name} " +
+                "#{struct_type} body to the original body encoding (#{encoding}). Consider using the " +
+                "`:preserve_exact_body_bytes` option to work around this."
+          return string
         end
       end
 
@@ -85,20 +74,15 @@ module VCR
         body = String.new(self.body.to_s)
 
         if VCR.configuration.preserve_exact_body_bytes_for?(self)
-          base_body_hash(body).merge('base64_string' => Base64.encode64(body))
+          base64_encoded = [body].pack('m')
+          base_body_hash(body).merge('base64_string' => base64_encoded)
         else
           base_body_hash(body).merge('string' => body)
         end
       end
 
-      if ''.respond_to?(:encoding)
-        def base_body_hash(body)
-          { 'encoding' => body.encoding.name }
-        end
-      else
-        def base_body_hash(body)
-          { }
-        end
+      def base_body_hash(body)
+        { 'encoding' => body.encoding.name }
       end
     end
 
@@ -416,9 +400,7 @@ module VCR
         case type
         when 'gzip'
           body_str = ''
-          args = [StringIO.new(body_str)]
-          args << { :encoding => 'ASCII-8BIT' } if ''.respond_to?(:encoding)
-          writer = Zlib::GzipWriter.new(*args)
+          writer = Zlib::GzipWriter.new(StringIO.new(body_str), encoding: 'ASCII-8BIT')
           writer.write(body)
           writer.close
           body_str
@@ -457,10 +439,7 @@ module VCR
 
       case type
       when 'gzip'
-        gzip_reader_options = {}
-        gzip_reader_options[:encoding] = 'ASCII-8BIT' if ''.respond_to?(:encoding)
-        yield Zlib::GzipReader.new(StringIO.new(body),
-                                   **gzip_reader_options).read
+        yield Zlib::GzipReader.new(StringIO.new(body), encoding: 'ASCII-8BIT').read
       when 'deflate'
         yield Zlib::Inflate.inflate(body)
       when 'identity', NilClass
